AFieldCheckboxList class

Inheritance

Constructors

AFieldCheckboxList({Key? key, required String label, required String identifier, List<int>? initialValue, bool readOnly = false, int minRequired = 0, required List<Option> options, void onChanged(List<int>?)?, int? flexible, bool expanded = false, EdgeInsets? margin, bool linkToAForm = true, VoidCallback? onSubmit})
const

Properties

customRules List<ARule<List<int>>>?
finalinherited
expanded bool
finalinherited
flexible int?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
identifier String
finalinherited
initialValue List<int>?
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
finalinherited
linkToAForm bool
finalinherited
margin EdgeInsets?
finalinherited
minRequired int
final
onChanged → void Function(List<int>?)?
finalinherited
onSubmit VoidCallback?
finalinherited
options List<Option>
final
padding EdgeInsets?
finalinherited
readOnly bool
finalinherited
readonly bool
finalinherited
required bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timerTime int
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() AFieldCheckboxListState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited