AFieldCNPJState class

Inheritance

Constructors

AFieldCNPJState()

Properties

backgroundColor Color
no setterinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
controller TextEditingController
getter/setter pairinherited
currentMask String
getter/setter pairinherited
customRules List<ARule<String>>
finalinherited
focusNode FocusNode
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
haveSuffixIcon bool
no setterinherited
hintText String?
getter/setter pairinherited
inputFormatters List<TextInputFormatter>
finalinherited
labelText String?
no setterinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
obscure bool
getter/setter pairinherited
rules List<ARule<String>>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timerTime int
getter/setter pairinherited
value String
getter/setter pairinherited
widget AFieldMasked
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
childBuild() Widget
inherited
clear() → void
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant AFieldMasked oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
errorText({EdgeInsets padding = const EdgeInsets.only(top: 0)}) Widget
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChanged(String? value) → void
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
requiredRule<T>(T? value) String?
inherited
setControllerCursor() → void
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setValue(String? value) → void
inherited
suffixIcon({double iconSize = 18}) Widget
inherited
suffixItems() List<Widget>
inherited
textField() Widget
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
validate() bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited