AFieldCPF class
- Inheritance
Constructors
-
AFieldCPF({Key? key, bool readOnly = false, bool required = false, String? initialValue = '', void onChanged(String?)?, bool? showIcon, int? flexible, bool expanded = false, EdgeInsets? margin, String? label = 'CPF', String identifier = 'cpf', Iterable<
String> ? autofillHints, bool autofocus = false, Widget? bottom, bool capitalize = false, bool clearable = false, List<ARule< ? customRules, Map<String> >String, RegExp> ? filter, double height = 46, bool linkToAForm = true, VoidCallback? onSubmit, void onUnfocus()?, EdgeInsets? padding, bool readonly = false, Widget? suffix}) -
const
Properties
-
autofillHints
→ Iterable<
String> ? -
finalinherited
- autofocus → bool
-
finalinherited
- bottom → Widget?
-
finalinherited
- capitalize → bool
-
finalinherited
- clearable → bool
-
finalinherited
-
customRules
→ List<
ARule< ?String> > -
finalinherited
- decoration → InputDecoration?
-
finalinherited
- denySpaces → bool
-
finalinherited
- expanded → bool
-
finalinherited
-
filter
→ Map<
String, RegExp> ? -
finalinherited
- flexible → int?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
finalinherited
- hintText → String?
-
finalinherited
- icon → IconData?
-
finalinherited
- identifier → String
-
finalinherited
- initialValue → String?
-
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
finalinherited
- label → String?
-
finalinherited
- linkToAForm → bool
-
finalinherited
- margin → EdgeInsets?
-
finalinherited
- mask → String
-
finalinherited
- maxLines → int
-
finalinherited
- onChanged → void Function(String?)?
-
finalinherited
- onSubmit → VoidCallback?
-
finalinherited
- onUnfocus → void Function()?
-
finalinherited
- padding → EdgeInsets?
-
finalinherited
- readOnly → bool
-
finalinherited
- readonly → bool
-
finalinherited
- required → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffix → Widget?
-
finalinherited
- timerTime → int
-
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → AFieldCPFState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited