AFieldDropDown<T> class

Inheritance
Implementers

Constructors

AFieldDropDown({required List<AOption<T>>? options, void onChanged(T?)?, Key? key, bool readOnly = false, bool required = false, required String? label, required String identifier, bool searchable = false, bool loading = false, T? initialValue, int? flexible, bool expanded = false, EdgeInsets? margin, double height = 46, double? width, WidgetBuilder? menuFooter, bool linkToAForm = true, VoidCallback? onSubmit, List<ARule<T>>? customRules, EdgeInsets? padding, bool readonly = false})
const

Properties

customRules List<ARule<T>>?
finalinherited
expanded bool
finalinherited
flexible int?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double
final
identifier String
finalinherited
initialValue → T?
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
finalinherited
linkToAForm bool
finalinherited
loading bool
final
margin EdgeInsets?
finalinherited
final
onChanged → void Function(T?)?
finalinherited
onSubmit VoidCallback?
finalinherited
options List<AOption<T>>?
final
padding EdgeInsets?
finalinherited
readOnly bool
finalinherited
readonly bool
finalinherited
required bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchable bool
final
timerTime int
finalinherited
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() AFieldDropDownState<AFieldDropDown<T>, T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited