AFieldDropDownState<TWidget extends AFieldDropDown<TValue>, TValue> class

Inheritance
Mixed-in types
Implementers

Constructors

AFieldDropDownState()

Properties

backgroundColor Color
no setterinherited
btnMargin EdgeInsets?
getter/setter pairinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
customRules List<ARule<TValue>>
finalinherited
filteredOptions List<AOption<TValue>>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pairinherited
labelText String?
no setter
loading bool
no setter
getter/setter pairinherited
getter/setter pairinherited
getter/setter pairinherited
minContentHeight double
getter/setter pairinherited
minContentWidth double
getter/setter pairinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
obscure bool
getter/setter pairinherited
options List<AOption<TValue>>?
no setter
parentContext BuildContext
getter/setter pairinherited
persistent bool
getter/setter pairinherited
rules List<ARule<TValue>>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedOption AOption<TValue>?
getter/setter pair
timerTime int
getter/setter pairinherited
value ↔ TValue?
getter/setter pairoverride
widget → TWidget
The current configuration.
no setterinherited
width double?
getter/setter pairinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
childBuild() Widget
override
clear() → void
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant TWidget oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
inherited
errorText({EdgeInsets padding = const EdgeInsets.only(top: 0)}) Widget
inherited
filterOptions([BuildContext? context]) → void
initMenu(BuildContext context, {bool persistent = false, required WidgetBuilder menu, WidgetBuilder? menuFooter, WidgetBuilder? menuHeader, double? width, double? height, EdgeInsets? btnMargin}) → void
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChanged(TValue? value) → void
override
onPressed() → void
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
requiredRule<T>(T? value) String?
inherited
setSelectedOption() → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setValue(TValue? value) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
validate() bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited