AFieldDropDownLazyState<T> class

Inheritance

Constructors

AFieldDropDownLazyState()

Properties

backgroundColor Color
no setterinherited
btnMargin EdgeInsets?
getter/setter pairinherited
context BuildContext
The location in the tree where this widget builds.
no setterinherited
customRules List<ARule<T>>
finalinherited
error bool
getter/setter pair
filteredOptions List<AOption<T>>
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pairinherited
labelText String?
no setterinherited
loading bool
getter/setter pairoverride-getter
getter/setter pairinherited
getter/setter pairinherited
getter/setter pairinherited
minContentHeight double
getter/setter pairinherited
minContentWidth double
getter/setter pairinherited
mounted bool
Whether this State object is currently in a tree.
no setterinherited
obscure bool
getter/setter pairinherited
options List<AOption<T>>
getter/setter pairoverride-getter
parentContext BuildContext
getter/setter pairinherited
persistent bool
getter/setter pairinherited
rules List<ARule<T>>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedOption AOption<T>?
getter/setter pairinherited
timerTime int
getter/setter pairinherited
value ↔ T?
getter/setter pairinherited
widget AFieldDropDownLazy<T>
The current configuration.
no setterinherited
width double?
getter/setter pairinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
childBuild() Widget
override
clear() → void
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant AFieldDropDownLazy<T> oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
errorText({EdgeInsets padding = const EdgeInsets.only(top: 0)}) Widget
inherited
filterOptions([BuildContext? context]) → void
inherited
initMenu(BuildContext context, {bool persistent = false, required WidgetBuilder menu, WidgetBuilder? menuFooter, WidgetBuilder? menuHeader, double? width, double? height, EdgeInsets? btnMargin}) → void
inherited
initState() → void
Called when this object is inserted into the tree.
override
loadData() → void
inherited
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChanged(T? value) → void
inherited
onPressed() → void
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
requiredRule<T>(T? value) String?
inherited
setSelectedOption() → void
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setValue(T? value) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
validate() bool
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited