AFieldSearch class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AField<
String> - AFieldText
- AFieldSearch
Constructors
-
AFieldSearch({Key? key, String identifier = "search", String? label = "Pesquisar", IconData? icon = Icons.search, required void onChanged(String?)?, String? initialValue, bool expanded = false, int? flexible, EdgeInsets? margin, double height = 46, Iterable<
String> ? autofillHints, bool autofocus = false, Widget? bottom, bool capitalize = false, List<ARule< ? customRules, bool denySpaces = false, String? hintText, TextInputType? keyboardType, bool linkToAForm = false, int maxLines = 1, VoidCallback? onSubmit, void onUnfocus()?, EdgeInsets? padding, bool readOnly = false, bool required = false, Widget? suffix})String> > -
const
Properties
-
autofillHints
→ Iterable<
String> ? -
finalinherited
- autofocus → bool
-
finalinherited
- bottom → Widget?
-
finalinherited
- capitalize → bool
-
finalinherited
- clearable → bool
-
finalinherited
-
customRules
→ List<
ARule< ?String> > -
finalinherited
- decoration → InputDecoration?
-
finalinherited
- denySpaces → bool
-
finalinherited
- expanded → bool
-
finalinherited
- flexible → int?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
finalinherited
- hintText → String?
-
finalinherited
- icon → IconData?
-
finalinherited
- identifier → String
-
finalinherited
- initialValue → String?
-
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
finalinherited
- label → String?
-
finalinherited
- linkToAForm → bool
-
finalinherited
- margin → EdgeInsets?
-
finalinherited
- maxLines → int
-
finalinherited
- onChanged → void Function(String?)?
-
finalinherited
- onSubmit → VoidCallback?
-
finalinherited
- onUnfocus → void Function()?
-
finalinherited
- padding → EdgeInsets?
-
finalinherited
- readOnly → bool
-
finalinherited
- readonly → bool
-
finalinherited
- required → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffix → Widget?
-
finalinherited
- timerTime → int
-
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → AFieldTextState< AFieldText> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited