AFieldText class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AField<
String> - AFieldText
- Implementers
Constructors
-
AFieldText({bool capitalize = false, TextInputType? keyboardType, bool clearable = false, int maxLines = 1, String? hintText, bool autofocus = false, IconData? icon, Widget? suffix, Widget? bottom, Iterable<
String> ? autofillHints, void onUnfocus()?, Key? key, bool readOnly = false, required String identifier, required String? label, bool required = false, List<ARule< ? customRules, bool denySpaces = false, double height = 46, void onChanged(String?)?, String? initialValue, int? flexible, bool expanded = false, EdgeInsets? margin, bool linkToAForm = true, VoidCallback? onSubmit, EdgeInsets? padding, bool readonly = false, int timerTime = 500, InputDecoration? decoration})String> > -
const
Properties
-
autofillHints
→ Iterable<
String> ? -
final
- autofocus → bool
-
final
- bottom → Widget?
-
final
- capitalize → bool
-
final
- clearable → bool
-
final
-
customRules
→ List<
ARule< ?String> > -
finalinherited
- decoration → InputDecoration?
-
final
- denySpaces → bool
-
final
- expanded → bool
-
finalinherited
- flexible → int?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- hintText → String?
-
final
- icon → IconData?
-
final
- identifier → String
-
finalinherited
- initialValue → String?
-
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- label → String?
-
finalinherited
- linkToAForm → bool
-
finalinherited
- margin → EdgeInsets?
-
finalinherited
- maxLines → int
-
final
- onChanged → void Function(String?)?
-
finalinherited
- onSubmit → VoidCallback?
-
finalinherited
- onUnfocus → void Function()?
-
final
- padding → EdgeInsets?
-
finalinherited
- readOnly → bool
-
finalinherited
- readonly → bool
-
finalinherited
- required → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffix → Widget?
-
final
- timerTime → int
-
finalinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → AFieldTextState< AFieldText> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited