AFieldTextState<TWidget extends AFieldText> class

Inheritance
Implementers

Constructors

AFieldTextState()

Properties

backgroundColor → Color
no setterinherited
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controller ↔ TextEditingController
getter/setter pair
currentMask ↔ String
getter/setter pair
customRules → List<ARule<String>>
finalinherited
focusNode ↔ FocusNode
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
haveSuffixIcon → bool
no setter
hintText ↔ String?
getter/setter pair
inputFormatters → List<TextInputFormatter>
final
labelText → String?
no setter
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
obscure ↔ bool
getter/setter pairinherited
rules → List<ARule<String>>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timerTime ↔ int
getter/setter pairinherited
value ↔ String
getter/setter pairoverride
widget → TWidget
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
childBuild() → Widget
override
clear() → void
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant TWidget oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
errorText({EdgeInsets padding = const EdgeInsets.only(top: 0)}) → Widget
inherited
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChanged(String? value) → void
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
requiredRule<T>(T? value) → String?
inherited
setControllerCursor() → void
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setValue(String? value) → void
override
suffixIcon({double iconSize = 18}) → Widget
suffixItems() → List<Widget>
textField() → Widget
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
validate() → bool
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited