AButton class

Inheritance
Implementers

Constructors

AButton({Key? key, String? text, String? textTitle, TextStyle? textStyle, TextAlign textAlign = TextAlign.center, IconData? icon, required dynamic onPressed()?, bool disabled = false, bool loading = false, Color? color, bool upperCase = true, Color? borderColor, double? borderRadius, double fontSize = 12, double iconSize = 18, FontWeight? fontWeight, double? height, double? width, double elevation = 2, IconData? landingIcon, Color? landingColor, Widget? landingImage, IconData? trailingIcon, Color? trailingColor, EdgeInsets padding = const EdgeInsets.all(10), EdgeInsets margin = EdgeInsets.zero, Color? textColor, bool outlined = false, MainAxisAlignment rowAlignment = MainAxisAlignment.center, bool singleLine = false, bool expanded = false, Widget? suffixChip, Widget? title, Widget? footer})
const

Properties

borderColor Color?
final
borderRadius double?
final
color Color?
final
disabled bool
final
elevation double
final
expanded bool
final
fontSize double
final
fontWeight FontWeight?
final
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
icon IconData?
final
iconSize double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
landingColor Color?
final
landingIcon IconData?
final
landingImage Widget?
final
loading bool
final
margin EdgeInsets
final
onPressed → dynamic Function()?
final
outlined bool
final
padding EdgeInsets
final
rowAlignment MainAxisAlignment
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleLine bool
final
suffixChip Widget?
final
text String?
final
textAlign TextAlign
final
textColor Color?
final
textStyle TextStyle?
final
textTitle String?
final
title Widget?
final
trailingColor Color?
final
trailingIcon IconData?
final
upperCase bool
final
width double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() AButtonState<AButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited