AFormState<T> class

Inheritance

Constructors

AFormState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
fieldStates Map<String, AFieldState<AField, dynamic>>
final
fieldValidated bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isLastPage bool
no setter
loading bool
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
page int
getter/setter pair
pageController PageController
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController
final
showAllForm bool
getter/setter pair
useDoubleColumn bool
no setter
widget AForm<T>
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
addField(AFieldState<AField, dynamic> fieldState) → void
bottomNavigationContainer() Widget
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
clear() → void
containerAppBar() Widget
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
defaultActions(Color primaryColor) List<Widget>
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant AForm<T> oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
form() Widget
getData() → T
initState() → void
Called when this object is inserted into the tree.
override
nextAction() Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBack() → void
onSubmit() → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
removeField(AFieldState<AField, dynamic> fieldState) → void
saveAction() Widget
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
setup() → void
showErrorMessage(String text) → void
spacedWidgets(List<Widget> widgets, {double? margin}) List<Widget>
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
validate() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited