AFormDialog<T> class

Inheritance

Constructors

AFormDialog({Key? key, dynamic initialData, Future loadInitialData()?, required String title, required bool persistent, required List<Widget> fields, required T fromJson(dynamic), required Future<String?> onSubmit(T), List<Widget>? actions, void onSuccess()?, bool obscureAll = false, double width = 400, List<Widget>? titleActions, String? submitText})
const

Properties

actions List<Widget>?
final
content List<Widget>?
finalinherited
fields List<Widget>
final
fromJson → T Function(dynamic)
final
hashCode int
The hash code for this object.
no setterinherited
height double?
finalinherited
initialData → dynamic
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadInitialData Future Function()?
final
obscureAll bool
final
onSubmit Future<String?> Function(T)
final
onSuccess → void Function()?
final
padding double
finalinherited
persistent bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
submitText String?
final
title String
finalinherited
titleActions List<Widget>?
finalinherited
useInternalScroll bool
finalinherited
width double
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() AFormDialogState<T, AFormDialog<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show<T>(BuildContext context, {required String title, bool persistent = false, List<Widget>? titleActions, List<Widget>? actions, required List<Widget> fields, required T fromJson(dynamic), required Future<String?> onSubmit(T), void onSuccess()?, dynamic initialData, Future loadInitialData()?, bool obscureAll = false, double width = 400, String? submitText}) Future<bool>
override