AButtonWithMenu class

Inheritance

Constructors

AButtonWithMenu({Key? key, String? text, String? textTitle, IconData? icon, bool disabled = false, bool loading = false, Color? color, bool upperCase = true, Color? borderColor, double? borderRadius, double fontSize = 12, double iconSize = 18, FontWeight? fontWeight, double? height, double? width, double elevation = 2, IconData? landingIcon, Widget? landingImage, IconData? trailingIcon, EdgeInsets padding = const EdgeInsets.all(10), Color? textColor, bool outlined = false, MainAxisAlignment rowAlignment = MainAxisAlignment.center, bool singleLine = false, bool expanded = false, Widget? suffixChip, EdgeInsets margin = EdgeInsets.zero, required WidgetBuilder menu, WidgetBuilder? menuFooter, bool persistent = false, double? menuWidth, double? menuHeight})
const

Properties

borderColor Color?
finalinherited
borderRadius double?
finalinherited
color Color?
finalinherited
disabled bool
finalinherited
elevation double
finalinherited
expanded bool
finalinherited
fontSize double
finalinherited
fontWeight FontWeight?
finalinherited
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double?
finalinherited
icon IconData?
finalinherited
iconSize double
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
landingColor Color?
finalinherited
landingIcon IconData?
finalinherited
landingImage Widget?
finalinherited
loading bool
finalinherited
margin EdgeInsets
finalinherited
final
final
final
final
onPressed → dynamic Function()?
finalinherited
outlined bool
finalinherited
padding EdgeInsets
finalinherited
persistent bool
final
rowAlignment MainAxisAlignment
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleLine bool
finalinherited
suffixChip Widget?
finalinherited
text String?
finalinherited
textAlign TextAlign
finalinherited
textColor Color?
finalinherited
textStyle TextStyle?
finalinherited
textTitle String?
finalinherited
title Widget?
finalinherited
trailingColor Color?
finalinherited
trailingIcon IconData?
finalinherited
upperCase bool
finalinherited
width double?
finalinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() AButtonMenuState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited