ATable<T> class

Inheritance

Constructors

ATable({Key? key, required List<ATableColumn<T>> columns, EdgeInsets rowPadding = const EdgeInsets.all(8), bool striped = true, int loaderLimit = 100, void onItemClicked(T item)?, required Future<List<T>> loadItems(int limit, int offset), Color? customRowColor(T)?, double fontSize = 14, double mobileBreakpointWidth = 400, double mobileHeaderWidth = 100, String emptyMessage = "Nenhum item encontrado"})
const

Properties

columns List<ATableColumn<T>>
final
customRowColor Color? Function(T)?
final
emptyMessage String
final
fontSize double
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loaderLimit int
final
loadItems Future<List<T>> Function(int limit, int offset)
final
mobileBreakpointWidth double
final
mobileHeaderWidth double
final
onItemClicked → void Function(T item)?
final
rowPadding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
striped bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() ATableState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited