ATableColumn<T> class

Constructors

ATableColumn({String? title, Widget? titleWidget, required ACellBuilder<T> cellBuilder, double? fixedWidth, int expanded = 1, EdgeInsets margin = const EdgeInsets.symmetric(horizontal: 8), TextAlign headerAlignment = TextAlign.left})
const

Properties

cellBuilder ACellBuilder<T>
final
expanded int
final
fixedWidth double?
final
hashCode int
The hash code for this object.
no setterinherited
headerAlignment TextAlign
final
margin EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final
titleWidget Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited