AField<T> class
abstract
- Inheritance
- Implementers
Constructors
-
AField({Key? key, required String? label, required String identifier, T? initialValue, void onChanged(T?)?, bool expanded = false, int? flexible, bool readOnly = false, bool required = false, bool readonly = false, List<
ARule< ? customRules, EdgeInsets? padding, EdgeInsets? margin, bool linkToAForm = true, VoidCallback? onSubmit, int timerTime = 500})T> > -
const
Properties
-
customRules
→ List<
ARule< ?T> > -
final
- expanded → bool
-
final
- flexible → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
final
- initialValue → T?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- linkToAForm → bool
-
final
- margin → EdgeInsets?
-
final
- onChanged → void Function(T?)?
-
final
- onSubmit → VoidCallback?
-
final
- padding → EdgeInsets?
-
final
- readOnly → bool
-
final
- readonly → bool
-
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timerTime → int
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited