AFieldOAB class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AField<
Map< String, dynamic> > - AFieldOAB
Constructors
-
AFieldOAB({Key? key, bool readOnly = false, String identifier = 'oab', String oabLabel = 'Número OAB', String ufLabel = 'UF', bool required = false, String? label, void onChanged(Map<
String, dynamic> ?)?, bool autofocus = false, Map<String, dynamic> ? initialValue = const <String, dynamic>{'number' : '', 'uf' : ''}, int? flexible, bool expanded = false, EdgeInsets? margin, bool linkToAForm = true, VoidCallback? onSubmit, List<ARule< ? customRules, EdgeInsets? padding, bool readonly = false})Map< >String, dynamic> > -
const
Properties
- autofocus → bool
-
final
-
customRules
→ List<
ARule< ?Map< >String, dynamic> > -
finalinherited
- expanded → bool
-
finalinherited
- flexible → int?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
finalinherited
-
initialValue
→ Map<
String, dynamic> ? -
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
finalinherited
- linkToAForm → bool
-
finalinherited
- margin → EdgeInsets?
-
finalinherited
- oabLabel → String
-
final
-
onChanged
→ void Function(Map<
String, dynamic> ?)? -
finalinherited
- onSubmit → VoidCallback?
-
finalinherited
- padding → EdgeInsets?
-
finalinherited
- readOnly → bool
-
finalinherited
- readonly → bool
-
finalinherited
- required → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timerTime → int
-
finalinherited
- ufLabel → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited