Option class
Constructors
Properties
-
children
→ List<
Option> ? -
final
- childrenType → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- initialSelected → bool?
-
final
- label → String
-
final
- parentId → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited