AForm<T> class
- Inheritance
Constructors
-
AForm({Key? key, required List<
Widget> fields, List<Widget> ? rightFields, required T fromJson(dynamic), List<Widget> actions = const <Widget>[], Color? backgroundColor, bool backIcon = true, bool backButton = false, bool obscureAll = false, dynamic initialData, String? submitText, EdgeInsets padding = const EdgeInsets.all(20), double fieldsPadding = 5, double actionsPadding = 5, required Future<String?> onSubmit(T), Future<void> onCancelled()?, void onSuccess()?, void onLoadingChange(bool loading)?, bool showAllForm = true, bool showDefaultAction = true, Color? actionColor, dynamic setterChanges(T)?, double minDualColumWidth = 600, Widget? fieldsTitle, Widget? rightFieldsTitle, Widget? topBar}) -
const
Properties
- actionColor → Color?
-
final
-
actions
→ List<
Widget> -
final
- actionsPadding → double
-
final
- backButton → bool
-
final
- backgroundColor → Color?
-
final
- backIcon → bool
-
final
-
fields
→ List<
Widget> -
final
- fieldsPadding → double
-
final
- fieldsTitle → Widget?
-
final
- fromJson → T Function(dynamic)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialData → dynamic
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minDualColumWidth → double
-
final
- obscureAll → bool
-
final
-
onCancelled
→ Future<
void> Function()? -
final
- onLoadingChange → void Function(bool loading)?
-
final
-
onSubmit
→ Future<
String?> Function(T) -
final
- onSuccess → void Function()?
-
final
- padding → EdgeInsets
-
final
-
rightFields
→ List<
Widget> ? -
final
- rightFieldsTitle → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setterChanges → dynamic Function(T)?
-
final
- showAllForm → bool
-
final
- showDefaultAction → bool
-
final
- submitText → String?
-
final
- topBar → Widget?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AForm< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
maybeOf(
BuildContext context) → AFormState?