AButtonMenuState class
- Inheritance
-
- Object
- State<
AButtonWithMenu> - AButtonState<
AButtonWithMenu> - AButtonMenuState
- Mixed-in types
Constructors
Properties
- backgroundColor → Color
-
no setterinherited
- borderColor → Color
-
no setterinherited
- borderRadius → BorderRadius
-
no setterinherited
- btnMargin ↔ EdgeInsets?
-
getter/setter pairinherited
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- elevation → double
-
no setterinherited
- foregroundColor → Color
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- haveBorder → bool
-
no setterinherited
- height ↔ double?
-
getter/setter pairinherited
- isActive → bool
-
no setterinherited
- isIcon → bool
-
no setterinherited
-
getter/setter pairinherited
-
getter/setter pairinherited
-
getter/setter pairinherited
- minContentHeight ↔ double
-
getter/setter pairinherited
- minContentWidth ↔ double
-
getter/setter pairinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- parentContext ↔ BuildContext
-
getter/setter pairinherited
- persistent ↔ bool
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → AButtonWithMenu
-
The current configuration.
no setterinherited
- width ↔ double?
-
getter/setter pairinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
inherited
-
inherited
-
content(
) → Widget -
inherited
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant AButtonWithMenu oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
initMenu(
BuildContext context, {bool persistent = false, double? width, double? height, EdgeInsets? btnMargin}) → void -
inherited
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
loadingIndicator(
) → Widget -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onPressed(
) → void -
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited